/**
 * Grid to manage subscribers.
 *
 * @class JustKnit.grid.Subscribers
 * @extends Ext.Panel
 * @param {Object} config An object of options.
 * @xtype justknit-grid-subscribers
 */

JustKnit.grid.Subscribers = function(config) {
    config = config || {};
    Ext.applyIf(config, {
        id: 'justknit-grid-subscribers',
        url: MODx.config.connector_url,
        baseParams: {
            action: 'JustKnit\\Processors\\Subscribers\\GetList',
        },
        fields:['id', 'subscriber_id', 'first_name', 'last_name', 'subscribedon', 'subscriber_blockedafter', 'subscriber_blocked'],
        autoHeight: true,
        paging: true,
        emptyText: _('justknit.subscribers_none'),
        remoteSort: true,
        columns: [
            {
                header: 'ID',
                dataIndex: 'id',
                sortable: true,
            },{
                header: 'UserID',
                dataIndex: 'subscriber_id',
                sortable: true,
            },{
                header: 'Vorname',
                dataIndex: 'first_name',
                sortable: true,
            },{
                header: 'Nachname',
                dataIndex: 'last_name',
                sortable: true,
            },{
                header: 'subscribedon',
                dataIndex: 'subscribedon',
                sortable: true,
            },{
                header: 'subscriber_blockedafter',
                dataIndex: 'subscriber_blockedafter',
                sortable: true,
            },{
                header: 'subscriber_blocked',
                dataIndex: 'subscriber_blocked',
                sortable: true,
            }
        ],
        tbar:[{
            text: _('justknit.subscriber_create'),
            handler: this.createSubscriber,
            scope: this
        },{
            xtype: 'textfield',
            emptyText: _('justknit.input_search_filter'),
            listeners: {
                'change': {fn: this.search, scope: this}
            }
        }]
    });
    JustKnit.grid.Subscribers.superclass.constructor.call(this, config);
};
Ext.extend(JustKnit.grid.Subscribers, MODx.grid.Grid, {
    search: function(tf,nv,ov) {
        var s = this.getStore();
        s.baseParams.query = tf.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    },
    createSubscriber: function(btn, e) {
        var win = MODx.load({
            xtype: 'justknit-window-subscriber-create-update',
            title: _('justknit.subscriber_create'),
            listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.show(e.target);

    }
});
Ext.reg('justknit-grid-subscribers', JustKnit.grid.Subscribers);

// Window
JustKnit.window.CreateUpdateSubscriber = function(config) {
    config = config || {};
    Ext.applyIf(config, {
        width: 480,
        closeAction: 'close',
        url: MODx.config.connector_url,
        action: 'JustKnit\\Processors\\Subscribers\\Create',
        fields: [{
            xtype: 'textfield',
            fieldLabel: _('justknit.subscriber_first_name'),
            name: 'first_name',
            anchor: '100%'
        },{
            xtype: 'textfield',
            fieldLabel: _('justknit.subscriber_last_name'),
            name: 'last_name',
            anchor: '100%'
        }]


    });
    JustKnit.window.CreateUpdateSubscriber.superclass.constructor.call(this, config);
};
Ext.extend(JustKnit.window.CreateUpdateSubscriber, MODx.Window);
Ext.reg('justknit-window-subscriber-create-update', JustKnit.window.CreateUpdateSubscriber);



