/**
 * Panel to manage Calc.
 *
 * @class JustKnit.panel.Calc
 * @extends Ext.Panel
 * @param {Object} config An object of options.
 * @xtype Justknit-panel-calc
 */

JustKnit.panel.Calc = function(config) {
    config = config || {};
    Ext.applyIf(config,{
        id: 'justknit-panel-calc'
        ,title: _('justknit.calc')
        ,layout: 'anchor'
        ,defaults: {
            border: false
        }
        ,items:[{
            html: '<p>'+_('justknit.calc_management_desc')+'</p>'
            ,xtype: 'modx-description'
        },{
            xtype: 'justknit-grid-calc'//'modx-description'//
        }]
    });
    JustKnit.panel.Calc.superclass.constructor.call(this,config);
};
Ext.extend(JustKnit.panel.Calc,Ext.Panel);
Ext.reg('justknit-panel-calc', JustKnit.panel.Calc);

JustKnit.grid.Calc = function(config) {
    config = config || {};
    Ext.applyIf(config,{
        id: 'justknit-grid-calc'
        ,url: MODx.config.connector_url
        ,cls: 'main-wrapper'
        ,baseParams: {
            action: 'JustKnit\\Processors\\Calc\\GetList'
        }
        ,fields:['id','resource_id', 'createdon', 'ccreatedby', 'editedon', 'editedby', 'len_w', 'len_h', 'qty_w', 'qty_h', 'calcname', 'pattern_meta', 'title', 'description', 'results']
        ,autoHeight: true
        ,paging: true
        ,emptyText: _('justknit.calc_none')
        ,remoteSort: true
        ,save_action: 'JustKnit\\Processors\\Calc\\UpdateFromGrid'
        ,autosave: true
        ,columns: [
            { header: _('justknit_calc.id') ,dataIndex: 'id' ,sortable: true ,editor: {xtype: 'textfield'} }
            ,{ header: _('justknit_calc.resource_id') ,dataIndex: 'resource_id' ,sortable: true }
            ,{ header: _('justknit_calc.resource_id') ,dataIndex: 'resource_id' ,sortable: true ,editor:{xtype: 'justknit-combo-resource', hiddenName: 'resource_id',displayField: 'alias',renderer: true } }
            //{xtype: 'justknit-combo-resource', hiddenName: 'resource_id',displayField: 'alias',renderer: true } 
            ,{ header: _('justknit_calc.ccreatedby') ,dataIndex: 'ccreatedby' ,sortable: true ,editor: {xtype: 'textfield'} }
            ,{ header: _('justknit_calc.editedon') ,dataIndex: 'editedon' ,sortable: true ,editor: {xtype: 'textfield'} }

        ]
        ,tbar:[{
            text: _('justknit.calc_create')
            ,handler: this.createCalc
            ,scope: this
//        },'->',{
            
        },'->',{
            xtype: 'justknit-combo-resource'
            ,id: 'justknit-calc-resource-filter'
            ,emptyText: _('justknit.calc_resource_filter')
            ,name: 'fltr_calc_resource'
            ,hiddenName: 'fltr_calc_resource'
            ,displayField: 'alias'
            ,valueField: 'resource_id'
//                store: new Ext.data.ArrayStore({
//                })
            ,listeners: {
                'select': {fn: this.filterByResource, scope: this}
            }

        },{
            text: _('justknit.reset_filter')
            ,handler: this.clearFilter
            ,scope: this
        },{
            xtype: 'textfield',
            emptyText: _('justknit.input_search_filter'),
            listeners: {
                'change': {fn: this.search, scope: this}
            }
        }]
    });
    JustKnit.grid.Calc.superclass.constructor.call(this, config);
};


Ext.extend(JustKnit.grid.Calc, MODx.grid.Grid, {
    search: function(tf,nv,ov) {
        var s = this.getStore();
        s.baseParams.query = tf.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    },clearFilter: function() {
    	this.getStore().baseParams = {
            action: 'JustKnit\\Processors\\Calc\\GetList'
    	};
        Ext.getCmp('justknit-calc-resource-filter').reset();
//        Ext.getCmp('justknit-clients-category-filter').reset();
//        Ext.getCmp('goodnews-clients-testdummy-filter').reset();
//        Ext.getCmp('goodnews-clients-active-filter').reset();
//        Ext.getCmp('goodnews-clients-search-filter').reset();
    	this.getBottomToolbar().changePage(1);
    }
    ,createCalc: function(btn, e) {
        var win = MODx.load({
            xtype: 'justknit-window-calc-create-update'
            ,title: _('justknit.calc_create')
            ,listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.show(e.target);

    }
    ,updateCalc: function(btn, e) {
        if (!this.menu.record || !this.menu.record.id ){
            return false;
        }
        var win = MODx.load({
            xtype: 'justknit-window-calc-create-update'
            ,title: _('justknit.calc_update')
            ,action: 'JustKnit\\Processors\\Calc\\Update'
            ,listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.fp.getForm().setValues(this.menu.record);
        win.show(e.target);

    }
    ,getMenu:function() {
        var m = [];
        m.push({
            text: _('justknit.calc_update')
            ,handler: this.updateCalc
        });
        m.push({
            text: _('justknit.calc_remove')
            ,handler: this.removeCalc
        });
        m.push('-');
        this.addContextMenuItem(m);
    }
    ,removeCalc: function(btn, e) {
        if (!this.menu.record){
            return false;
        }
        MODx.msg.confirm({
            title: _('justknit.calc_remove')
            ,text: _('justknit.calc_remove_confirm')
            ,url: this.config.url
            ,params: {
                action: 'JustKnit\\Processors\\Calc\\Remove'
                ,id: this.menu.record.id
            }
            ,listeners:{
                'success': { fn: function() {this.refresh();}, scope: this}
            }
        });
    }
    ,filterByResource: function(combo) {
//        var s = [];
//        Ext.getCmp('justknit-clients-group-filter').reset();
//        var s = Ext.getCmp('justknit-clients-group-filter');
//        s.baseParams.groupfilter = combo.getValue();
//        s.baseParams.groupfilter = Ext.getCmp('justknit-clients-group-filter').getValue();
        var s = this.getStore();
        s.baseParams.groupfilter = combo.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    }
});
Ext.reg('justknit-grid-calc', JustKnit.grid.Calc);
// JustKnit.window.CreateUpdateCalc
JustKnit.window.CreateUpdateCalc = function(config) {
    config = config || {};
    Ext.applyIf(config, {
        width: 700
        ,closeAction: 'close'
        ,url: MODx.config.connector_url
        ,preventRender: true
        ,action: 'JustKnit\\Processors\\Calc\\Create'
        ,fields: [
            new Ext.Panel ({
                layout:"column"
                ,defaults:{layout:'form',style:'margin:0'}
                ,items:[
{columnWidth:.3,items:[{xtype: 'hidden' ,name: 'id'}]}
,{columnWidth:.3,items:[{xtype: 'justknit-combo-resource',hiddenName: 'resource_id',displayField: 'alias' ,fieldLabel: _('justknit_calc.resource_id') ,name: 'resource_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.createdon') ,name: 'createdon'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.ccreatedby') ,name: 'ccreatedby'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.editedon') ,name: 'editedon'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.editedby') ,name: 'editedby'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.len_w') ,name: 'len_w'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.len_h') ,name: 'len_h'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.qty_w') ,name: 'qty_w'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.qty_h') ,name: 'qty_h'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.calcname') ,name: 'calcname'}]}
// JSON: ,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.pattern_meta') ,name: 'pattern_meta'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.title') ,name: 'title'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.description') ,name: 'description'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_calc.results') ,name: 'results'}]}

                ]
            })
        ]

    });
    JustKnit.window.CreateUpdateCalc.superclass.constructor.call(this, config);
};
Ext.extend(JustKnit.window.CreateUpdateCalc, MODx.Window);
Ext.reg('justknit-window-calc-create-update', JustKnit.window.CreateUpdateCalc);

