/**
 * Panel to manage Dim.
 *
 * @class JustKnit.panel.Dim
 * @extends Ext.Panel
 * @param {Object} config An object of options.
 * @xtype Justknit-panel-dim
 */

JustKnit.panel.Dim = function(config) {
    config = config || {};
    Ext.applyIf(config,{
        id: 'justknit-panel-dim'
        ,title: _('justknit.dim')
        ,layout: 'anchor'
        ,defaults: {
            border: false
        }
        ,items:[{
            html: '<p>'+_('justknit.dim_management_desc')+'</p>'
            ,xtype: 'modx-description'
        },{
            xtype: 'justknit-grid-dim'//'modx-description'//
        }]
    });
    JustKnit.panel.Dim.superclass.constructor.call(this,config);
};
Ext.extend(JustKnit.panel.Dim,Ext.Panel);
Ext.reg('justknit-panel-dim', JustKnit.panel.Dim);

JustKnit.grid.Dim = function(config) {
    config = config || {};
    Ext.applyIf(config,{
        id: 'justknit-grid-dim'
        ,url: MODx.config.connector_url
        ,cls: 'main-wrapper'
        ,baseParams: {
            action: 'JustKnit\\Processors\\Dim\\GetList'
        }
        ,fields:['id','calc_id','resource_id','calcedby','len','qty','pre','post','dimname','dtn_d']
        ,autoHeight: true
        ,paging: true
        ,emptyText: _('justknit.dim_none')
        ,remoteSort: true
        ,save_action: 'JustKnit\\Processors\\Dim\\UpdateFromGrid'
        ,autosave: true
        ,columns: [
{ header: _('justknit_dim.id') ,dataIndex: 'id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.calc_id') ,dataIndex: 'calc_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.resource_id') ,dataIndex: 'resource_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.calcedby') ,dataIndex: 'calcedby' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.len') ,dataIndex: 'len' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.qty') ,dataIndex: 'qty' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.pre') ,dataIndex: 'pre' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.post') ,dataIndex: 'post' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.dimname') ,dataIndex: 'dimname' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_dim.dtn_d') ,dataIndex: 'dtn_d' ,sortable: true ,editor: {xtype: 'textfield'} }

        ]
        ,tbar:[{
            text: _('justknit.dim_create')
            ,handler: this.createDim
            ,scope: this
//        },'->',{

        },'->',{
            xtype: 'justknit-combo-resource'
            ,id: 'justknit-dim-resource-filter'
            ,emptyText: _('justknit.dim_resource_filter')
            ,name: 'fltr_dim_resource'
            ,hiddenName: 'fltr_dim_resource'
            ,displayField: 'alias'
            ,valueField: 'resource_id'
//                store: new Ext.data.ArrayStore({
//                })
            ,listeners: {
                'select': {fn: this.filterByResource, scope: this}
            }

        },{
            text: _('justknit.reset_filter')
            ,handler: this.clearFilter
            ,scope: this
        },{
            xtype: 'textfield',
            emptyText: _('justknit.input_search_filter'),
            listeners: {
                'change': {fn: this.search, scope: this}
            }
        }]
    });
    JustKnit.grid.Dim.superclass.constructor.call(this, config);
};

Ext.extend(JustKnit.grid.Dim, MODx.grid.Grid, {
    search: function(tf,nv,ov) {
        var s = this.getStore();
        s.baseParams.query = tf.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    },clearFilter: function() {
    	this.getStore().baseParams = {
            action: 'JustKnit\\Processors\\Dim\\GetList'
    	};
        Ext.getCmp('justknit-dim-resource-filter').reset();
//        Ext.getCmp('justknit-clients-category-filter').reset();
//        Ext.getCmp('goodnews-clients-testdummy-filter').reset();
//        Ext.getCmp('goodnews-clients-active-filter').reset();
//        Ext.getCmp('goodnews-clients-search-filter').reset();
    	this.getBottomToolbar().changePage(1);
    }
    ,createDim: function(btn, e) {
        var win = MODx.load({
            xtype: 'justknit-window-dim-create-update'
            ,title: _('justknit.dim_create')
            ,listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.show(e.target);

    }
    ,updateDim: function(btn, e) {
        if (!this.menu.record || !this.menu.record.id ){
            return false;
        }
        var win = MODx.load({
            xtype: 'justknit-window-dim-create-update'
            ,title: _('justknit.dim_update')
            ,action: 'JustKnit\\Processors\\Dim\\Update'
            ,listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.fp.getForm().setValues(this.menu.record);
        win.show(e.target);

    }
    ,getMenu:function() {
        var m = [];
        m.push({
            text: _('justknit.dim_update')
            ,handler: this.updateDim
        });
        m.push({
            text: _('justknit.dim_remove')
            ,handler: this.removeDim
        });
        m.push('-');
        this.addContextMenuItem(m);
    }
    ,removeDim: function(btn, e) {
        if (!this.menu.record){
            return false;
        }
        MODx.msg.confirm({
            title: _('justknit.dim_remove')
            ,text: _('justknit.dim_remove_confirm')
            ,url: this.config.url
            ,params: {
                action: 'JustKnit\\Processors\\Dim\\Remove'
                ,id: this.menu.record.id
            }
            ,listeners:{
                'success': { fn: function() {this.refresh();}, scope: this}
            }
        });
    }
    ,filterByResource: function(combo) {

        var s = this.getStore();
        s.baseParams.groupfilter = combo.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    }
});
Ext.reg('justknit-grid-dim', JustKnit.grid.Dim);
// JustKnit.window.CreateUpdateDim
JustKnit.window.CreateUpdateDim = function(config) {
    config = config || {};
    Ext.applyIf(config, {
        width: 700
        ,closeAction: 'close'
        ,url: MODx.config.connector_url
        ,preventRender: true
        ,action: 'JustKnit\\Processors\\Dim\\Create'
        ,fields: [
            new Ext.Panel ({
                layout:"column"
                ,defaults:{layout:'form',style:'margin:0'}
                ,items:[
{columnWidth:.3,items:[{xtype: 'hidden' ,name: 'id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.calc_id') ,name: 'calc_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.resource_id') ,name: 'resource_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.calcedby') ,name: 'calcedby'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.len') ,name: 'len'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.qty') ,name: 'qty'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.pre') ,name: 'pre'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.post') ,name: 'post'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.dimname') ,name: 'dimname'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_dim.dtn_d') ,name: 'dtn_d'}]}


                ]
            })
        ]

    });
    JustKnit.window.CreateUpdateDim.superclass.constructor.call(this, config);
};
Ext.extend(JustKnit.window.CreateUpdateDim, MODx.Window);
Ext.reg('justknit-window-dim-create-update', JustKnit.window.CreateUpdateDim);

