/**
 * Panel to manage Transaction.
 *
 * @class JustKnit.panel.Transaction
 * @extends Ext.Panel
 * @param {Object} config An object of options.
 * @xtype Justknit-panel-transaction
 */

JustKnit.panel.Transaction = function(config) {
    config = config || {};
    Ext.applyIf(config,{
        id: 'justknit-panel-transaction'
        ,title: _('justknit.transaction')
        ,layout: 'anchor'
        ,defaults: {
            border: false
        }
        ,items:[{
            html: '<p>'+_('justknit.transaction_management_desc')+'</p>'
            ,xtype: 'modx-description'
        },{
            xtype: 'justknit-grid-transaction'//'modx-description'//
        }]
    });
    JustKnit.panel.Transaction.superclass.constructor.call(this,config);
};
Ext.extend(JustKnit.panel.Transaction,Ext.Panel);
Ext.reg('justknit-panel-transaction', JustKnit.panel.Transaction);

JustKnit.grid.Transaction = function(config) {
    config = config || {};
    Ext.applyIf(config,{
        id: 'justknit-grid-transaction'
        ,url: MODx.config.connector_url
        ,cls: 'main-wrapper'
        ,baseParams: {
            action: 'JustKnit\\Processors\\Transaction\\GetList'
        }
        ,fields:['id','client_id','order_id','product_id','transaction_id','buyer_id','DS24_order_id','DS24_product_id','transaction_date','transaction_type','amount','amount_netto','amount_payout','amount_provider','amount_vat','amount_vendor','currency','email','pay_method']
        ,autoHeight: true
        ,paging: true
        ,emptyText: _('justknit.transaction_none')
        ,remoteSort: true
        ,save_action: 'JustKnit\\Processors\\Transaction\\UpdateFromGrid'
        ,autosave: true
        ,columns: [
{ header: _('justknit_transaction.') ,dataIndex: '' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.client_id') ,dataIndex: 'client_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.order_id') ,dataIndex: 'order_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.product_id') ,dataIndex: 'product_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.transaction_id') ,dataIndex: 'transaction_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.buyer_id') ,dataIndex: 'buyer_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.DS24_order_id') ,dataIndex: 'DS24_order_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.DS24_product_id') ,dataIndex: 'DS24_product_id' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.transaction_date') ,dataIndex: 'transaction_date' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.transaction_type') ,dataIndex: 'transaction_type' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.amount') ,dataIndex: 'amount' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.amount_netto') ,dataIndex: 'amount_netto' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.amount_payout') ,dataIndex: 'amount_payout' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.amount_provider') ,dataIndex: 'amount_provider' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.amount_vat') ,dataIndex: 'amount_vat' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.amount_vendor') ,dataIndex: 'amount_vendor' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.currency') ,dataIndex: 'currency' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.email') ,dataIndex: 'email' ,sortable: true ,editor: {xtype: 'textfield'} }
,{ header: _('justknit_transaction.pay_method') ,dataIndex: 'pay_method' ,sortable: true ,editor: {xtype: 'textfield'} }


        ]
        ,tbar:[{
            text: _('justknit.transaction_create')
            ,handler: this.createTransaction
            ,scope: this
//        },'->',{

        },'->',{
            xtype: 'justknit-combo-resource'
            ,id: 'justknit-transaction-resource-filter'
            ,emptyText: _('justknit.transaction_resource_filter')
            ,name: 'fltr_transaction_resource'
            ,hiddenName: 'fltr_transaction_resource'
            ,displayField: 'alias'
            ,valueField: 'resource_id'
//                store: new Ext.data.ArrayStore({
//                })
            ,listeners: {
                'select': {fn: this.filterByResource, scope: this}
            }

        },{
            text: _('justknit.reset_filter')
            ,handler: this.clearFilter
            ,scope: this
        },{
            xtype: 'textfield',
            emptyText: _('justknit.input_search_filter'),
            listeners: {
                'change': {fn: this.search, scope: this}
            }
        }]
    });
    JustKnit.grid.Transaction.superclass.constructor.call(this, config);
};

Ext.extend(JustKnit.grid.Transaction, MODx.grid.Grid, {
    search: function(tf,nv,ov) {
        var s = this.getStore();
        s.baseParams.query = tf.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    },clearFilter: function() {
    	this.getStore().baseParams = {
            action: 'JustKnit\\Processors\\Transaction\\GetList'
    	};
        Ext.getCmp('justknit-transaction-resource-filter').reset();
//        Ext.getCmp('justknit-clients-category-filter').reset();
//        Ext.getCmp('goodnews-clients-testdummy-filter').reset();
//        Ext.getCmp('goodnews-clients-active-filter').reset();
//        Ext.getCmp('goodnews-clients-search-filter').reset();
    	this.getBottomToolbar().changePage(1);
    }
    ,createTransaction: function(btn, e) {
        var win = MODx.load({
            xtype: 'justknit-window-transaction-create-update'
            ,title: _('justknit.transaction_create')
            ,listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.show(e.target);

    }
    ,updateTransaction: function(btn, e) {
        if (!this.menu.record || !this.menu.record.id ){
            return false;
        }
        var win = MODx.load({
            xtype: 'justknit-window-transaction-create-update'
            ,title: _('justknit.transaction_update')
            ,action: 'JustKnit\\Processors\\Transaction\\Update'
            ,listeners: {
                'success': {fn: function() {this.refresh();}, scope: this}
            }
        });
        win.fp.getForm().setValues(this.menu.record);
        win.show(e.target);

    }
    ,getMenu:function() {
        var m = [];
        m.push({
            text: _('justknit.transaction_update')
            ,handler: this.updateTransaction
        });
        m.push({
            text: _('justknit.transaction_remove')
            ,handler: this.removeTransaction
        });
        m.push('-');
        this.addContextMenuItem(m);
    }
    ,removeTransaction: function(btn, e) {
        if (!this.menu.record){
            return false;
        }
        MODx.msg.confirm({
            title: _('justknit.transaction_remove')
            ,text: _('justknit.transaction_remove_confirm')
            ,url: this.config.url
            ,params: {
                action: 'JustKnit\\Processors\\Transaction\\Remove'
                ,id: this.menu.record.id
            }
            ,listeners:{
                'success': { fn: function() {this.refresh();}, scope: this}
            }
        });
    }
    ,filterByResource: function(combo) {

        var s = this.getStore();
        s.baseParams.groupfilter = combo.getValue();
        this.getBottomToolbar().changePage(1);
        this.refresh();
    }
});
Ext.reg('justknit-grid-transaction', JustKnit.grid.Transaction);
// JustKnit.window.CreateUpdateTransaction
JustKnit.window.CreateUpdateTransaction = function(config) {
    config = config || {};
    Ext.applyIf(config, {
        width: 700
        ,closeAction: 'close'
        ,url: MODx.config.connector_url
        ,preventRender: true
        ,action: 'JustKnit\\Processors\\Transaction\\Create'
        ,fields: [
            new Ext.Panel ({
                layout:"column"
                ,defaults:{layout:'form',style:'margin:0'}
                ,items:[
{columnWidth:.3,items:[{xtype: 'hidden' ,name: 'id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.client_id') ,name: 'client_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.order_id') ,name: 'order_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.product_id') ,name: 'product_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.transaction_id') ,name: 'transaction_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.buyer_id') ,name: 'buyer_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.DS24_order_id') ,name: 'DS24_order_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.DS24_product_id') ,name: 'DS24_product_id'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.transaction_date') ,name: 'transaction_date'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.transaction_type') ,name: 'transaction_type'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.amount') ,name: 'amount'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.amount_netto') ,name: 'amount_netto'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.amount_payout') ,name: 'amount_payout'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.amount_provider') ,name: 'amount_provider'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.amount_vat') ,name: 'amount_vat'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.amount_vendor') ,name: 'amount_vendor'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.currency') ,name: 'currency'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.email') ,name: 'email'}]}
,{columnWidth:.3,items:[{xtype: 'textfield' ,fieldLabel: _('justknit_transaction.pay_method') ,name: 'pay_method'}]}


                ]
            })
        ]

    });
    JustKnit.window.CreateUpdateTransaction.superclass.constructor.call(this, config);
};
Ext.extend(JustKnit.window.CreateUpdateTransaction, MODx.Window);
Ext.reg('justknit-window-transaction-create-update', JustKnit.window.CreateUpdateTransaction);
