<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

use JustKnit\Register\Register;

/**
 * JustKnitRegister
 *
 * Snippet which handles new subscriptions and processes register forms.
 *
 * @var modX $modx
 * @var Register $register
 * @var array $scriptProperties
 *
 * PROPERTIES
 * these values are usually passed from DS24 in a $_POST array
 *
 * @order_id string The ID of the order delivered by DS24.
 *                   (default: '')
 * @quantity int quantity of products
 *                   (default: 0)
 * @email string user's email address
 *                   (default: '')
 * @language string user's language
 *                   (default: '')
 * @buyer_id string The ID of the user delivered by DS24.
 *                   (default: '')
 * @address_first_name string user's first_name
 *                   (default: '')
 * @address_last_name string user's last_name
 *                   (default: '')
 * @merchant_id string Vendor ID from DS24
 *                   (default: '1134577')
 * @country string user's country
 *                   (default: '')
 * @affiliate_id string Affilate ID from DS24
 *                   (default: '')
 * @orderform_id string ID of used order form
 *                   (default: '')
 * @campaignkey string key of ca,pains origin
 *                   (default: '')
 * @currency string currency
 *                   (default: '')
 * @amount float amount of current order
 *                   (default: 0)
 * @vat_amount float vfat of current order
 *                   (default: 0)
 * @vat_rate float vfat rate of current order
 *                   (default: 0)
 * @monthly_amount float
 *                   (default: 0)
 * @monthly_vat_amount float
 *                   (default: 0)
 * @number_of_installments int
 *                   (default: 0)
 * @billing_type string type of payment ['single_payment', monthly]
 *                   (default: '')
 * @product_id string DS24 ID of product
 *                   (default: '')
 * @product_language string language of product
 *                   (default: '')
 * @product_name string Name of the ordered product
 *                   (default: '')
 * @product_delivery_type string Product type
 *                   (default: '')
 * @address_id string Address ID sent by DS24
 *                   (default: '')
 * @address_street string user's address_street
 *                   (default: '')
 * @address_street2 string user's address_street2
 *                   (default: '')
 * @address_city string user's address_city
 *                   (default: '')
 * @address_state string user's address_state
 *                   (default: '')
 * @address_zipcode string user's address_zipcode
 *                   (default: '')
 * @address_country string user's address_country
 *                   (default: '')
 * @address_phone_no string user's address_phone_no
 *                   (default: '')
 * @address_mobile_no string user's address_mobile_no
 *                   (default: '')
 * @address_company string user's address_company
 *                   (default: '')
 * @address_salutation string user's address_salutation
 *                   (default: '')
 * @address_title string user's address_title
 *                   (default: '')
 * @address_street_name string user's address_street_name
 *                   (default: '')
 * @address_street_number string user's address_street_number
 *                   (default: '')
 * @sha_sign string sha_sign sent by DS24 to compare with self generated hash
 *                   (default: '')
 * @typk string ThankYouPageKey for hashing response to DS24
 *                   (default: '') *
 * @package justknit
 * @subpackage snippets
 */

$register = new Register($modx, $scriptProperties);  // ruft auf: src/Register/Register.php
$controller = $register->loadController('RegisterDS24');  //darin diese Funktion
$output = $controller->run($scriptProperties);
return $output;
