<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

namespace JustKnit\Controllers\Register;

use MODX\Revolution\modX;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use MODX\Revolution\modUserSetting;
use JustKnit\Model\JustKnitClientMeta;
use JustKnit\Controllers\Register\Base;

class ClientForgotPassword extends Base {
    

    const FORGOT_PASSWORD_EXTERNAL_USER = 'forgotpassword.external_user';
    const MODE_FORGOT_PASSWORD = 'forgot-password';
    
    /** @var modUser $user */
    public $user;
    /** @var modUserProfile $profile */
    public $profile;
    /** @var string $templateToLoad */
    public $templateToLoad = 'jkForgotPassTpl';
    /** @var string $templateTypeToLoad */
    public $templateTypeToLoad = 'modChunk';
    /** @var array $placeholders */
    public $placeholders = array();
    /** @var string $usernameField */
    public $usernameField = 'username';
    /** @var int $emailsSent */
    public $emailsSent = 0;

    public function initialize() {
        $this->modx->lexicon->load('justknit:register');
        $this->setDefaultProperties(array(
            'tpl' => 'jkForgotPassTpl',
            'tplType' => 'modChunk',
            'sentTpl' => 'jkForgotPassSentTpl',
            'sentTplType' => 'modChunk',
            'emailTpl' => 'jkForgotPassEmail',
            'emailTplAlt' => '',
            'emailTplType' => 'modChunk',
            'emailSubject' => '',
            'preHooks' => '',
            'resetResourceId' => 1,
            'redirectTo' => false,
            'redirectParams' => '',
            'submitVar' => 'justknit_fp_service',
            'emailFrom' => '',
            'emailFromName' => '',
            'emailSender' => '',
            'emailReplyTo' => '',
            'justknitfp.errors_nf' => 'success',
        ));
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword initialize() : Und??? wird der Scheiß geladen?');
//justknitfp.errors
    }
    /**
     * Process the controller
     * @return string
     */
    public function process() {
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword process() : Und??? wird der Scheiß geladen?');

//        $this->templateToLoad = $this->getProperty('tpl');
//        $this->templateTypeToLoad = $this->getProperty('tplType');

        /* get the request URI */
        $this->placeholders['justknitfp.request_uri'] = empty($_POST['request_uri']) ? $this->getRequestURI() : $_POST['request_uri'];
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword $this->hasPost() : '. $this->hasPost(). ',  '. $this->getRequestURI(). ',  '. $_POST['request_uri']);

        if ($this->hasPost()) {
            $this->handlePost();
            $fields = $this->dictionary->toArray();
            $fields = $this->escapePlaceholders($fields);
            foreach ($fields as $k => $v) {
                $this->placeholders['justknitfp.post.'.$k] = $v;
            }
        }
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword $this->placeholders : Und??? '. print_r($this->placeholders,1));

        $this->modx->toPlaceholders($this->placeholders);

//        return $this->modx->getChunk($this->templateToLoad,$this->placeholders,$this->templateTypeToLoad);
    }

    /**
     * Handle the form submission
     * @return boolean
     */
    public function handlePost() {
        $this->dictionary = $this->register->loadDictionary();

        $success = false;
        $this->sanitizeFields();

        if ($this->runPreHooks()) {
            $this->fetchUser();

            if (empty($this->user)) {
                $this->placeholders['justknitfp.errors'] = $this->modx->lexicon('justknit.user_err_nf_'.$this->usernameField);
                $this->placeholders['justknitfp.errors_nf'] = $this->modx->lexicon('justknit.user_err_nf');
            } else {
                if ($this->account) {
                    $this->placeholders['email'] = $this->dictionary->get('email');

                    $this->sendPasswordResetEmail();
                    $this->templateToLoad = $this->getProperty('sentTpl');
                    $this->templateTypeToLoad = $this->getProperty('sentTplType');
                    $this->checkForRedirect();
                    $this->placeholders['justknitfp.errors'] = $this->modx->lexicon('justknit.msg_email_sent');
                    $this->placeholders['justknitfp.errors_nf'] = 'success';
                }
            }
        }
        return $success;
    }

    /**
     * Wrap errors in an error tpl
     * @param string $message
     * @return string
     */
//    public function formatError($message) {
//        $errTpl = $this->getProperty('errTpl','jkErrTpl');
//        $errTplType = $this->getProperty('errTplType','modChunk');
//        return $this->modx->getChunk($errTpl, array('msg' => $message),$errTplType);

//    }

    /**
     * Fetch the user to update, also allowing external user updating
     * @return modUser
     */
    public function fetchUser() {
        $fields = $this->dictionary->toArray();
        $this->usernameField = 'username';
        $this->account = true;
        $alias = 'modUser';
        if (empty($fields['username']) && !empty($fields['email'])) {
            $this->usernameField = 'email';
            $alias = 'Profile';
        }
        /* if the preHook didn't set the user info, find it by email/username */
        if (empty($fields[ClientForgotPassword::FORGOT_PASSWORD_EXTERNAL_USER])) {
            /* get the user dependent on the retrieval method */
            $this->user = $this->getUserByField($this->usernameField,$fields[$this->usernameField],$alias);
            if ($this->user) {
                $fields = array_merge($fields,$this->user->toArray());
                $this->profile = $this->user->getOne('Profile');
                if ($this->profile) { /* merge in profile */
                    $fields = array_merge($this->profile->toArray(),$fields);
                }
                /* check if the user is active */                
                if ($fields['blockedafter'] < time()) {
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] blockedafter abgelaufen'. $test.' '.time());
                    $this->placeholders['justknitfp.errors'] = $this->modx->lexicon('justknit.msg_account_expired');
                    $this->placeholders['justknitfp.errors_nf'] = $this->modx->lexicon('justknit.user_err_nf');                    
                    $this->account = false;
                }
            }
        }
        $this->dictionary->fromArray($fields);
        return $this->user;
    }

    /**
     * Check to see if the form has been submitted
     * @return boolean
     */
    public function hasPost() {
        $submitVar = $this->getProperty('submitVar','justknit_fp_service');
        if (empty($_POST)) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword $this->hasPost() : $_POST is empty');
        }
        if (empty($_POST[$submitVar])) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword $this->hasPost() : empty($_POST['.$submitVar.'] is empty');
        }
        
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword $this->hasPost() : '. print_r($_POST,1));
        
        return !empty($_POST) && !empty($_POST[$submitVar]);
    }

    /**
     * Sanitize the values sent on the form
     * @return void
     */
    public function sanitizeFields() {
        $fields = $this->dictionary->toArray();
        foreach ($fields as $k => $v) {
            $fields[$k] = str_replace(array('[',']'),array('&#91;','&#93'),$v);
        }
        $this->dictionary->fromArray($fields);
    }

    /**
     * Run any preHooks to process before submitting the form
     * @return boolean
     */
    public function runPreHooks() {
        $success = true;
        $preHooks = $this->getProperty('preHooks','');
        if (!empty($preHooks)) {
            $this->loadHooks('preHooks');
            $this->preHooks->loadMultiple($preHooks,$this->dictionary->toArray(),array(
                'mode' => ClientForgotPassword::MODE_FORGOT_PASSWORD,
            ));
            /* process preHooks */
            if ($this->preHooks->hasErrors()) {
                $success = false;
                $this->modx->toPlaceholders($this->preHooks->getErrors(),$this->getProperty('errorPrefix'));

                $errorMsg = $this->preHooks->getErrorMessage();
                $errorOutput = $this->formatError($errorMsg);
                $this->modx->setPlaceholder('errors',$errorOutput);
            }

            $values = $this->preHooks->getValues();
            if (!empty($values)) {
                $this->dictionary->fromArray($values);
            }
        }
        return $success;
    }

    /**
     * Send an email to the user with a confirmation URL to reset their password at
     * @return void
     */
    public function sendPasswordResetEmail() {
        $fields = $this->dictionary->toArray();

        /* generate a password and encode it and the username into the url */
        $password = $this->modx->user->generatePassword();
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientForgotPassword $password : '. $password);
        
        $confirmParams = array(
            'lp' => $this->base64url_encode($password),
            'lu' => $this->base64url_encode($fields['username'])
        );
        $confirmUrl = $this->modx->makeUrl($this->getProperty('resetResourceId',1),'',$confirmParams,'full');

        /* set the email properties */
        $emailProperties = $fields;
        $emailProperties['confirmUrl'] = $confirmUrl;
        $emailProperties['password'] = $password;
        $emailProperties['tpl'] = $this->getProperty('emailTpl');
        $emailProperties['tplAlt'] = $this->getProperty('emailTplAlt','');
        $emailProperties['tplType'] = $this->getProperty('emailTplType');
        $emailProperties['emailFrom'] = $this->getProperty('emailFrom');
        $emailProperties['emailFromName'] = $this->getProperty('emailFromName');
        $emailProperties['emailSender'] = $this->getProperty('emailSender');
        $emailProperties['emailReplyTo'] = $this->getProperty('emailReplyTo');

        /* now set new password to cache to prevent middleman attacks */
        $this->modx->cacheManager->set('justknit/resetpassword/'.md5($fields['id'].':'.$fields['username']),$password);

        $emailSubject = $this->getProperty('emailSubject','');
        $subject = !empty($emailSubject) ? $emailSubject : $this->modx->getOption('justknit.forgot_password_email_subject',null,$this->modx->lexicon('justknit.forgot_password_email_subject'));
        $this->sendEmail($fields['email'],$fields['username'],$subject,$emailProperties);
        $this->emailsSent++;
    }

    /**
     * Redirect the user to another page after successful form submission, if desired
     * @return boolean
     */
    public function checkForRedirect() {
        $redirectTo = $this->getProperty('redirectTo',false,'isset');
        /* if redirecting, do so here */
        if (!empty($redirectTo)) {
            $redirectParams = $this->getProperty('redirectParams','');
            if (!empty($redirectParams)) $redirectParams = $this->modx->fromJSON($redirectParams);
            $url = $this->modx->makeUrl($redirectTo,'',$redirectParams,'full');
            $this->modx->sendRedirect($url);
        } 
        return !empty($redirectTo);
    }
}
