<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

namespace JustKnit\Controllers\Register;

use MODX\Revolution\modX;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use MODX\Revolution\modUserSetting;
use JustKnit\Model\JustKnitClientMeta;
use JustKnit\Controllers\Register\Base;

class ClientLogin extends Base {

    const FORGOT_PASSWORD_EXTERNAL_USER = 'forgotpassword.external_user';
    const MODE_FORGOT_PASSWORD = 'forgot-password';
    const MODE_LOGIN = 'login';
    const MODE_LOGOUT = 'logout';
/**
 * So jetzt weiß ich wo der fehler liegt. Ich rendere ja keine chunks sondern will, dann nur die Placeholder gefüllt werden.
 * Daher ist bei mir das Formular leer. und der submitVar wird nicht gesetzt.
 */
    /**
     * Load default properties for this controller.
     *
     * @return void
     */
    public function initialize()
    {
        $this->setDefaultProperties(array(
            'loginViaEmail' => false,
//            'loginViaEmail' => true,
            'loginTpl' => 'lgnLoginTpl',
            'logoutTpl' => 'lgnLogoutTpl',
            'loggedinResourceId' => '',
            'loggedoutResourceId' => '',
            'loginMsg' => '',
            'logoutMsg' => '',
            'preHooks' => '',
            'tplType' => 'modChunk',
            'actionKey' => 'service',
            'loginKey' => 'login',
            'logoutKey' => 'logout',
            'errorPrefix' => 'error',
            'errTpl' => 'lgnErrTpl',
            'errTplType' => 'modChunk',
            'rememberMeKey' => 'rememberme',
            'loginContext' => $this->modx->context->get('key'),
            'contexts' => '',
            'jsonResponse' => false,
            'redirectToPrior' => false,

        ));

        if (!empty($_REQUEST['login_context'])) {
            $this->setProperty('loginContext',$_REQUEST['login_context']);
        }
        if (!empty($_REQUEST['add_contexts'])) {
            $this->setProperty('contexts',$_REQUEST['add_contexts']);
        }
        $this->isAuthenticated = $this->modx->user->isAuthenticated($this->getProperty('loginContext'));
        $isLoggedIn = $this->isAuthenticated ? true : false;
        $this->modx->setPlaceholder('isLoggedIn', $isLoggedIn);
        $this->modx->lexicon->load('justknit:register');
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] initialize()-001 justknit.login_title :'.$this->modx->lexicon('justknit.login_title'));
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] initialize()-001 $this->isAuthenticated :?'.$this->isAuthenticated.'? $this->getProperty(loginContext)'. $this->getProperty('loginContext') . ' properties: '.print_r($this->getProperties(), 1));
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] initialize()-001 $_SESSION :'.print_r($_SESSION,1));
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] initialize()-001 $_REQUEST :'.print_r($_REQUEST,1));
    }
    /**
     * Process the controller
     * @return string
     */
    public function process() {
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] process()-001 '.print_r($_REQUEST, 1));

        if (!empty($_REQUEST[$this->getProperty('actionKey','service')])) {
            $this->handleRequest();
        }
        $content = $this->renderForm();
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] process()-002 $content '.$content);
        return $this->output($content);

    }

    /**
     * Render the logout or login form
     * @return string
     */
    public function renderForm() {
        $redirectToPrior = $this->getProperty('redirectToPrior',false,'isset');
        $tpl = $this->isAuthenticated ? $this->getProperty('logoutTpl') : $this->getProperty('loginTpl');
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] initialize()-001 $this->isAuthenticated :?'.$this->isAuthenticated.'? ');
        $actionMsg = $this->isAuthenticated
            ? $this->getProperty('logoutMsg',$this->modx->lexicon('login.logout'))
            : $this->getProperty('loginMsg',$this->modx->lexicon('login'));

        $this->modx->setPlaceholder('actionMsg', $actionMsg);
        $phs = $this->isAuthenticated ? $this->getProperties() : array_merge($this->getProperties(), $_POST);

        /* make sure to strip out logout GET parameter to prevent ghost logout */
        $logoutKey = $this->getProperty('logoutKey','logout');
        if (!$redirectToPrior) {
            $phs['request_uri'] = str_replace(array('?service='.$logoutKey,'&service='.$logoutKey,'&amp;service='.$logoutKey),'',$_SERVER['REQUEST_URI']);
        } else {
            $phs['request_uri'] = str_replace(array('?service='.$logoutKey,'&service='.$logoutKey,'&amp;service='.$logoutKey),'',$_SERVER['HTTP_REFERER']);
        }

        $phs = $this->escapePlaceholders($phs);

        /* properly build logout url */
        if ($this->isAuthenticated) {
//            $phs['lifetime'] = $this->setLifetime();
            $phs['logoutUrl'] = $phs['request_uri'];
            $phs['logoutUrl'] .= strpos($phs['logoutUrl'],'?') ? ($this->modx->getOption('xhtml_urls',null,false) ? '&amp;' : '&') : '?';
            $phs['logoutUrl'] .= $phs['actionKey'].'='.$phs['logoutKey'];
            $phs['logoutUrl'] = str_replace(array('?=', '&=', '&amp;='), '', $phs['logoutUrl']);
        }
// no ReCaptcha for normal Client-Login
//        $this->loadReCaptcha();

        if ($this->isAuthenticated && $this->getProperty('loggedinResourceId') && $this->modx->resource->get('id') != $this->getProperty('loggedinResourceId')) {
            $url = $this->modx->makeUrl($this->getProperty('loggedinResourceId'), '', '', 'full');
            $this->modx->sendRedirect($url);
        }
        if (!$this->isAuthenticated && $this->getProperty('loggedoutResourceId') && $this->modx->resource->get('id') != $this->getProperty('loggedoutResourceId')) {
            $url = $this->modx->makeUrl($this->getProperty('loggedoutResourceId'), '', '', 'full');
            $this->modx->sendRedirect($url);
        }
        //get user data and merge to placeholders
        if ($this->isAuthenticated) {
            $this->user =& $this->modx->user;
//            $phs['lifetime'] = $this->setLifetime();
            $this->clientmeta = $this->getClientMeta();
            if (is_object($this->clientmeta)) {
                $phs = array_merge($this->clientmeta->toArray(),$phs);
            }
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] renderForm()-001 $phs '.print_r($phs, 1));
        }

        $this->modx->toPlaceholders($phs);
//        $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] renderForm()-001 $getPlaceholders '.print_r($this->getPlaceholders(), 1));
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] renderForm()-001 '.print_r($this->getProperties(), 1));
//        return $this->register->getChunk($tpl,$phs,$this->getProperty('tplType','modChunk'));
    }

    /**
     * Either output the content or set it as a placeholder
     * @param string $content
     * @return string
     */
    public function output($content = '') {
        $toPlaceholder = $this->getProperty('toPlaceholder','');
        if (!empty($toPlaceholder)) {
            $this->modx->setPlaceholder($toPlaceholder,$content);
            return '';
        }
        return $content;
    }
    /**
     * Handle any POST request
     *
     * @return void
     */
    public function handleRequest() {
        $this->register->loadDictionary();
        $actionKey = $this->getProperty('actionKey','service');
//$this->modx->log(modX::LOG_LEVEL_ERROR,'[JustKnit] handleRequest()-001 $actionKey '. $actionKey);
        if (!empty($_POST) && isset($_POST[$actionKey]) && !$this->isAuthenticated) {
            if ($_POST[$actionKey] == $this->getProperty('loginKey','login')) {
//$this->modx->log(modX::LOG_LEVEL_ERROR,'[JustKnit] handleRequest()-002 Hurra jetzt wird login() geladen. $_POST[$actionKey] '. $_POST[$actionKey]);
                $this->login();
            } else {
//$this->modx->log(modX::LOG_LEVEL_ERROR,'login.invalid_post'.$this->modx->lexicon('login.invalid_post',array(
//                    'action' => $_POST[$actionKey],
//                )));
            }
        } elseif ($_REQUEST[$actionKey] == $this->getProperty('logoutKey','logout') && $this->isAuthenticated) {
//$this->modx->log(modX::LOG_LEVEL_ERROR,'[JustKnit] handleRequest()-003 Hurra jetzt wird logout() geladen. $_POST[$actionKey] '. $_POST[$actionKey]);
            $this->logout();
        }
    }
    /**
     * Handle a Login submission
     *
     * @return void
     */
    public function login() {
        /* set default POST vars if not in form */
        if (empty($_POST['login_context'])) $_POST['login_context'] = $this->getProperty('loginContext');

        if ($this->runPreLoginHooks()) {
            $response = $this->runLoginProcessor();
            /* if we've got a good response, proceed */
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] $response '. print_r($response, 1));
            if (!empty($response) && !$response->isError()) {
//$this->modx->log( modX::LOG_LEVEL_ERROR,'Hurra, jetzt wird gleich runPostLoginHooks() geladen. '. print_r($_SESSION,1));
                $this->runPostLoginHooks($response);

                /* process posthooks for login */
                if ($this->register->postHooks->hasErrors()) {
//$this->modx->log( modX::LOG_LEVEL_ERROR,'BLÖÖD, postHooks-> hat Fehler.');
                    $errors = $this->postHooks->getErrors();
                    $errorMsg = $this->postHooks->getErrorMessage();
                    // Return JSON posthook errors if requested.
                    if ($this->getProperty('jsonResponse')) {
                        $jsonErrorOutput = array(
                            'success'   => false,
                            'message'   => $errorMsg,
                            'errors'    => $errors
                        );
                        header('Content-Type: application/json;charset=utf-8');
                        exit($this->modx->toJSON($jsonErrorOutput));
                    }
                    $errorPrefix = $this->getProperty('errorPrefix','error');
                    $this->modx->toPlaceholders($errors,$errorPrefix);
                    $this->modx->toPlaceholder('message',$errorMsg,$errorPrefix);
                } else {
//$this->modx->log(modX::LOG_LEVEL_ERROR,'Hurra, postHooks-> hat keine Fehler');
                    // Return JSON success response if requested.
                    if ($this->getProperty('jsonResponse')) {
                        $jsonSuccessOutput = array(
                            'success'   => true,
                            'message'   => $this->getProperty('loginMsg')
                        );
                        header('Content-Type: application/json;charset=utf-8');
                        exit($this->modx->toJSON($jsonSuccessOutput));
                    }
                    $this->redirectAfterLogin($response);
                }

            /* login failed, output error */
            } else {
                $this->checkForRedirectOnFailedAuth($response);
                $errorOutput = $this->prepareFailureMessage($response,$this->modx->lexicon('login.login_err'));
                $this->modx->setPlaceholder('errors', $errorOutput);
            }
        }
    }
    /**
     * Run any preHooks before logging in
     *
     * @return boolean
     */
    public function runPreLoginHooks() {
        $success = true;

        /* do pre-login hooks */
        $this->register->loadHooks('preHooks');
//        $this->loadHooks('preHooks');
        $tmp = $this->register->dictionary->toArray();
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] $this->register->dictionary->toArray() '. print_r($tmp, 1));
        $this->register->preHooks->loadMultiple($this->getProperty('preHooks',''),$tmp,array(
            'mode' => ClientLogin::MODE_LOGIN,
        ));

        /* process prehooks */
        if ($this->register->preHooks->hasErrors()) {
            $errors = $this->register->preHooks->getErrors();
            // Return JSON prehook errors if requested.
            if ($this->getProperty('jsonResponse')) {
                $jsonErrorOutput = array(
                    'success'   => false,
                    'errors'    => $errors
                );
                header('Content-Type: application/json;charset=utf-8');
                exit($this->modx->toJSON($jsonErrorOutput));
            }
            $this->modx->toPlaceholders($errors,$this->getProperty('errorPrefix','error'));

            $errorMsg = $this->preHooks->getErrorMessage();
            $errorOutput = $this->modx->getChunk($this->getProperty('errTpl'), array('msg' => $errorMsg));
            $this->modx->setPlaceholder('errors',$errorOutput);
            $success = false;
        }
        return $success;
    }

    /**
     * @return modProcessorResponse
     */
    public function runLoginProcessor() {
        $loginViaEmail = $this->getProperty('loginViaEmail', false);

        $this->fields = $this->register->dictionary->toArray();
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] $properties '. print_r($this->fields, 1));
        /* send to login processor and handle response */
        $properties = array(
            'login_context' => $this->getProperty('loginContext'),
            'add_contexts'  => $this->getProperty('contexts',''),
//            'username'      => $fields['username'],
//            'password'      => $fields['password'],
//            'returnUrl'     => $fields['returnUrl'],
            'username'      => $this->fields['username'],
            'password'      => $this->fields['password'],
            'returnUrl'     => $this->fields['returnUrl'],

            'rememberme'    => !empty($fields[$this->getProperty('rememberMeKey','rememberme')]) ? true : false,
        );
        if ($loginViaEmail) {
//            $processorsPath = $this->config['processorsPath'];
            $processorsPath = $this->config['processorsPath'];
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientLogin: $processorsPath.  '. $processorsPath);

//            return $this->runProcessor('ClientLogin');
//            return $this->modx->runProcessor('ClientLogin', $properties);
//            return $this->modx->runProcessor('ClientLogin', $properties,  array('processors_path' => $processorsPath));
// So jetzt hat es endlich geklappt, dass mein eigenen Processor geladen wird.
// und das Login mit email klappt auch.
return $this->modx->runProcessor('JustKnit\\Processors\\Register\\ClientLogin', $properties);
//
//            return $this->modx->runProcessor('ClientLogin', $properties, array('processors_path' => $processorsPath));
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientLogin: Jetzt ist mein eigenen Processor geladen worden.  ');
        } else {

            return $this->modx->runProcessor('security/login', $properties);
        }
    }
    /**
     * @param modProcessorResponse $response
     * @param string $defaultErrorMessage
     * @return string
     */
    public function prepareFailureMessage(\MODX\Revolution\Processors\ProcessorResponse $response,$defaultErrorMessage = '') {
        $errorOutput = '';
        $errTpl = $this->getProperty('errTpl');
        $errors = $response->getFieldErrors();
        $message = $response->getMessage();
        if (!empty($errors)) {
            // Return JSON login errors if requested.
            if ($this->getProperty('jsonResponse')) {
                $jsonErrorOutput = array(
                    'success'   => false,
                    'message'   => $message,
                    'errors'    => $errors
                );
                header('Content-Type: application/json;charset=utf-8');
                exit($this->modx->toJSON($jsonErrorOutput));
            }
            foreach ($errors as $error) {
                $errorOutput .= $this->modx->getChunk($errTpl, $error);
            }
        } elseif (!empty($message)) {
            // Return JSON error message in response if requested.
            if ($this->getProperty('jsonResponse')) {
                $jsonErrorOutput = array(
                    'success'   => false,
                    'message'   => $message
                );
                header('Content-Type: application/json;charset=utf-8');
                exit($this->modx->toJSON($jsonErrorOutput));
            }
            $errorOutput = $this->modx->getChunk($errTpl, array('msg' => $message));
        } else {
            // Return JSON default error if requested.
            if ($this->getProperty('jsonResponse')) {
                $jsonErrorOutput = array(
                    'success'   => false,
                    'message'   => $defaultErrorMessage
                );
                header('Content-Type: application/json;charset=utf-8');
                exit($this->modx->toJSON($jsonErrorOutput));
            }
            $errorOutput = $this->modx->getChunk($errTpl, array('msg' => $defaultErrorMessage));
        }
        return $errorOutput;
    }

//Bitego\\GoodNews\\Processors\\Subscribers\\AssignMulti
    /**
     * Check to see if the user wants to redirect to a separ
     * @param modProcessorResponse $response
     * @return void
     * MODX\Revolution\Processors\ProcessorResponse
     */
    public function checkForRedirectOnFailedAuth(\MODX\Revolution\Processors\ProcessorResponse $response) {
        $redirectToOnFailedAuth = $this->getProperty('redirectToOnFailedAuth',false,'isset');
        if ($redirectToOnFailedAuth && $redirectToOnFailedAuth != $this->modx->resource->get('id')) {
            $p = array(
                'u' => $this->dictionary->get('username'),
            );
            $message = $response->getMessage();
            if (!empty($message)) $params['m'] = $message;
            $url = $this->modx->makeUrl($redirectToOnFailedAuth,'',$p,'full');
            $this->modx->sendRedirect($url);
        }
    }
    /**
     * ALERT: Hier werden zusätzliche $fields gefüllt:
     *
     */

    /**
     * Run any postHooks specified after the user has logged in
     *
     * @param modProcessorResponse $response
     * @return void
     */
    public function runPostLoginHooks(\MODX\Revolution\Processors\ProcessorResponse $response) {
        $responseArray = $response->getObject();

        /* do post hooks */
        $postHooks = $this->getProperty('postHooks','');
//        $this->loadHooks('postHooks');
        $this->register->loadHooks('postHooks');
        $fields = $_POST;
        $fields['response'] =& $responseArray;
        $fields['contexts'] =& $contexts;
        $fields['loginContext'] =& $loginContext;
        $fields['loginResourceId'] =& $loginResourceId;
        $this->register->postHooks->loadMultiple($postHooks,$fields,array(
            'mode' => ClientLogin::MODE_LOGIN,
        ));

    }

    /**
     * Redirect the user after logging them in
     *
     * @param modProcessorResponse $response
     * @return void
     */
    public function redirectAfterLogin(\MODX\Revolution\Processors\ProcessorResponse $response) {
        $responseArray = $response->getObject();
        /* allow dynamic redirection handling */
        $redirectBack = $this->modx->getOption('redirectBack',$_REQUEST,$this->getProperty('redirectBack',''));
        $redirectBackParams = $this->modx->getOption('redirectBackParams',$_REQUEST,$this->getProperty('redirectBackParams',''));
        if (!empty($redirectBackParams)) {
            $redirectBackParams = $this->register->decodeParams($redirectBackParams);
        }
        /* otherwise specify a specific resource to redirect to */
        $loginResourceId = $this->getProperty('loginResourceId',$redirectBack);
        /* login posthooks succeeded, now redirect */

        if (!empty($loginResourceId)) {
            $loginResourceParams = $this->getProperty('loginResourceParams',$redirectBackParams);
            if (!empty($loginResourceParams) && !is_array($loginResourceParams)) {
                $loginResourceParams = $this->modx->fromJSON($loginResourceParams);
            }
            $url = $this->modx->makeUrl($loginResourceId,'',$loginResourceParams,'full');
            $this->modx->sendRedirect($url);
        } elseif (!empty($responseArray) && !empty($responseArray['url'])) {
            $this->modx->sendRedirect($responseArray['url']);
        } else {
            $this->modx->sendRedirect($this->modx->getOption('site_url'));
        }
    }

    public function logout() {
        /* set default REQUEST vars if not provided */
        if (empty($_REQUEST['login_context'])) $_REQUEST['login_context'] = $this->getProperty('loginContext');

        if ($this->runPreLogoutHooks()) {
            /* send to logout processor and handle response for each context */
            /** @var modProcessorResponse $response */
            $response = $this->modx->runProcessor('security/logout',array(
                'login_context' => $this->getProperty('loginContext',$this->modx->context->get('key')),
                'add_contexts' => $this->getProperty('contexts',''),
            ));

            /* if successful logout */
            if (!empty($response) && !$response->isError()) {
                $this->runPostLogoutHooks($response);
                // Return JSON logout success
                if ($this->getProperty('jsonResponse')) {
                    $jsonSuccessOutput = array(
                        'success'   => true,
                        'message'   => $this->getProperty('logoutMsg')
                    );
                    header('Content-Type: application/json;charset=utf-8');
                    exit($this->modx->toJSON($jsonSuccessOutput));
                }
                $this->redirectAfterLogout($response);

            /* logout failed, output error */
            } else {
                $errorOutput = $this->prepareFailureMessage($response,$this->modx->lexicon('login.logout_err'));
                $this->modx->setPlaceholder('errors', $errorOutput);
            }
        }
    }

    /**
     * @return boolean
     */
    public function runPreLogoutHooks() {
        $success = true;
        $this->register->loadHooks('preHooks');
        $this->register->preHooks->loadMultiple($this->getProperty('preHooks',''),$this->register->dictionary->toArray(),array(
            'mode' => ClientLogin::MODE_LOGOUT,
        ));

        if ($this->register->preHooks->hasErrors()) {
            $errors = $this->register->preHooks->getErrors();
            $errorMsg = $this->register->preHooks->getErrorMessage();
            // Return JSON login errors if requested.
            if ($this->getProperty('jsonResponse')) {
                $jsonErrorOutput = array(
                    'success'   => false,
                    'message'   => $errorMsg,
                    'errors'    => $errors
                );
                header('Content-Type: application/json;charset=utf-8');
                exit($this->modx->toJSON($jsonErrorOutput));
            }
            $this->modx->toPlaceholders($errors,$this->getProperty('errorPrefix','error'));
            $errorOutput = $this->modx->getChunk($this->getProperty('errTpl'), array('msg' => $errorMsg));
            $this->modx->setPlaceholder('errors',$errorOutput);
            $success = false;
        }
        return $success;
    }

    /**
     * Run any post-logout hooks
     *
     * @param modProcessorResponse $response
     * @return boolean
     */
    public function runPostLogoutHooks(\MODX\Revolution\Processors\ProcessorResponse $response) {
        $success = true;

        /* do post hooks for logout */
        $postHooks = $this->getProperty('postHooks','');
        $this->register->loadHooks('postHooks');
        $fields = $this->register->dictionary->toArray();
        $fields['response'] = $response->getObject();
        $fields['contexts'] =& $contexts;
        $fields['loginContext'] =& $loginContext;
        $fields['logoutResourceId'] =& $logoutResourceId;
        $this->register->postHooks->loadMultiple($postHooks,$fields,array(
            'mode' => ClientLogin::MODE_LOGOUT,
        ));

        /* log posthooks errors */
        if ($this->register->postHooks->hasErrors()) {
            $errors = $this->register->postHooks->getErrors();
            //$this->modx->log(modX::LOG_LEVEL_ERROR,'[Login] Post-Hook errors: '.print_r($errors,true));
            $errorMsg = $this->register->postHooks->getErrorMessage();
            if (!empty($errorMsg)) {
                //$this->modx->log(modX::LOG_LEVEL_ERROR,'[Login] Post-Hook error: '.$errorMsg);
            }
            $success = false;
            // Return JSON posthook logout errors if requested.
            if ($this->getProperty('jsonResponse')) {
                $jsonErrorOutput = array(
                    'success'   => false,
                    'message'   => $errorMsg,
                    'errors'    => $errors
                );
                header('Content-Type: application/json;charset=utf-8');
                exit($this->modx->toJSON($jsonErrorOutput));
            }
        }
        return $success;
    }

    /**
     * Redirect the user after they logout
     *
     * @param modProcessorResponse $response
     * @return void
     */
    public function redirectAfterLogout(\MODX\Revolution\Processors\ProcessorResponse $response) {
        $responseArray = $response->getObject();

        /* redirect */
        $logoutResourceId = $this->getProperty('logoutResourceId',0);
        if (!empty($responseArray) && !empty($responseArray['url'])) {
            $this->modx->sendRedirect($responseArray['url']);
        } elseif (!empty($logoutResourceId)) {
            $logoutResourceParams = $this->getProperty('logoutResourceParams','');
            if (!empty($logoutResourceParams)) {
                $logoutResourceParams = $this->modx->fromJSON($logoutResourceParams);
            }
            $url = $this->modx->makeUrl($logoutResourceId,'',$logoutResourceParams,'full');
            $this->modx->sendRedirect($url);
        } else {
            $this->modx->sendRedirect($_SERVER['REQUEST_URI']);
        }
    }

    /**
     * Set the cookie lifetime dependent on blocked after
     *
     * @param KeineAhnung
     * @return void
     *
     * TODO: Hier vllt noch die Lifetime vom Cookie voreinstellen. Damit der User nicht
     * länger eingelogged bleibt als sein Abo läuft??
     */
    public function setLifetime(){

    }

}
