<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

namespace JustKnit\Controllers\Register; 
use MODX\Revolution\modX;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use MODX\Revolution\modUserSetting;
use JustKnit\Model\JustKnitClientMeta;
use JustKnit\Controllers\Register\Base;

class ClientResetPassword extends Base {
    /** @var modUser $user */
    public $user;
    /** @var string $username */
    protected $username = '';
    /** @var string $password */
    protected $password = '';

    protected $errors = array ();

    public function initialize() {
        $this->setDefaultProperties(array(
            'tpl' => 'lgnResetPassTpl',
            'tplType' => 'modChunk',
            'changePasswordTpl' => 'lgnResetPassChangePassTpl',
            'changePasswordTplType' => 'modChunk',
            'changePasswordSubmitVar' => 'logcp-submit',
            'fieldConfirmNewPassword' => 'password_new_confirm',
            'fieldNewPassword' => 'password_new',
            'errTpl' => 'lgnErrTpl',
            'placeholderPrefix' => 'logcp.',
            'loginResourceId' => 1,
            'debug' => false,
            'autoLogin' => false,
            'forceChangePassword' => false,
            'expiredTpl' => 'lgnExpiredTpl',
            'expiredTplType' => 'modChunk',
        ));
$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Reset Und??: initialize()');        
        $this->modx->lexicon->load('justknit:register');
        
    }

    /**
     * Process the controller
     * @return string
     */
    public function process() {
$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Reset Und??: process()');          
        $this->getUser();
$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Reset Und??: process() empty($this->user)'. empty($this->user));          

        if (empty($this->user)) return $this->modx->getChunk($this->getProperty('expiredTpl'),array(),$this->getProperty('expiredTplType','modChunk'));
        if (!$this->verifyIdentity()) return $this->modx->getChunk($this->getProperty('expiredTpl'),array(),$this->getProperty('expiredTplType','modChunk'));

        if ($this->getProperty('forceChangePassword') == true) {
            if (!empty($_POST) && isset($_POST[$this->getProperty('submitVar','logcp-submit')])) {
                $changed = $this->handleChangePasswordForm();
                if ($changed !== true) {
                    return $changed;
                }
            } else {
                return $this->showChangePasswordForm();
            }
        }

        if (!$this->changePassword()) {
            return '';
        }

//        $this->eraseCache();

        if ($this->getProperty('autoLogin') == true) {
            $this->autoLogin();
        }

        $this->fireEvents();
        return $this->getResponse();
    }

    public function getUser() {
        /* get user from query params */
        if (!$_REQUEST['lu'] || !$_REQUEST['lp']) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientResetPassword: No request parameters');
            return null;
        }
        
        $this->username = $this->base64url_decode($_REQUEST['lu']);
        $this->password = $this->base64url_decode($_REQUEST['lp']);
        if (empty($this->username) || empty($this->password)) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] ClientResetPassword: No user found');
            return null;
        }
        
        /* validate we have correct user */
        $this->user = $this->modx->getObject(modUser::class,array('username' => $this->username));
        return $this->user;
    }

    /**
     * Validate password to prevent middleman attacks
     * @return boolean
     */
    public function verifyIdentity() {
        $cacheKey = 'justknit/resetpassword/'.md5($this->user->get('id').':'.$this->user->get('username'));
        $cachePass = $this->modx->cacheManager->get($cacheKey);
        $verified = $cachePass == $this->password;
$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Reset Und??: process() $cacheKey '. $cacheKey . ' , '.$cachePass. ' , '.$this->password.' , '.$verified);          

        return $verified;
    }

    /**
     * Erase the cached user data
     * @return void
     */
    public function eraseCache() {
        $cacheKey = 'justknit/resetpassword/'.md5($this->user->get('id').':'.$this->user->get('username'));
        $this->modx->cacheManager->delete($cacheKey);
    }

    /**
     * Change the User's password to the new one
     * @return bool
     */
    public function changePassword() {
        $saved = true;
        /* change password */
        $version = $this->modx->getVersionData();
        if (version_compare($version['full_version'],'2.1.0-rc1') >= 0) {
            $this->user->set('password',$this->password);
        } else {
            $this->user->set('password',md5($this->password));
        }
        if (!$this->getProperty('debug',false,'isset')) {
            $saved = $this->user->save();
        }
        return $saved;
    }

    /**
     * Fire change password events
     * @return void
     */
    public function fireEvents() {
        $this->modx->invokeEvent('OnWebChangePassword', array (
            'userid' => $this->user->get('id'),
            'username' => $this->user->get('username'),
            'userpassword' => $this->password,
            'user' => &$this->user,
            'newpassword' => $this->password,
        ));
        $this->modx->invokeEvent('OnUserChangePassword', array (
            'userid' => $this->user->get('id'),
            'username' => $this->user->get('username'),
            'userpassword' => $this->password,
            'user' => &$this->user,
            'newpassword' => $this->password,
        ));
    }

    /**
     * Return the response chunk
     * @return string
     */
    public function getResponse() {
        $placeholders = array(
            'username' => $this->user->get('username'),
            'loginUrl' => $this->modx->makeUrl($this->getProperty('loginResourceId',1)),
        );
    $this->placeholders['justknit.success_reset'] = $this->modx->lexicon('justknit.success_reset');        

//        return $this->modx->getChunk($this->getProperty('tpl'),$placeholders,$this->getProperty('tplType','modChunk'));
    }

    public function showChangePasswordForm() {
        $placeholderPrefix = rtrim($this->getProperty('placeholderPrefix', 'logcp.'), '.');
        $this->modx->toPlaceholders(array(
            'lp' => $this->base64url_encode($this->password),
            'lu' => $this->base64url_encode($this->username)
        ), $placeholderPrefix);
        return $this->modx->getChunk($this->getProperty('changePasswordTpl'), array(), $this->getProperty('changePasswordTplType', 'modChunk'));
    }

    /**
     * Validate the form with FormIt-style validation
     * @return array
     */
    public function validate() {
        $this->loadValidator();
        $fields = $this->validator->validateFields($this->dictionary,$this->getProperty('validate',''));
        foreach ($fields as $k => $v) {
            $fields[$k] = str_replace(array('[',']'),array('&#91;','&#93;'),$v);
        }
        $this->dictionary->fromArray($fields);

        return $this->validator->getErrors();
    }

    /**
     * Remove the submitVar from the fields array
     * @return void
     */
    public function removeSubmitVar() {
        $submitVar = $this->getProperty('changePasswordSubmitVar','logcp-submit');
        if (!empty($submitVar)) {
            $this->dictionary->remove($submitVar);
        }
    }

    public function handleChangePasswordForm() {
        $this->loadDictionary();
        $this->errors = $this->validate();
        $placeholderPrefix = rtrim($this->getProperty('placeholderPrefix', 'logcp.'), '.');
        $errorPrefix = ($placeholderPrefix) ? $placeholderPrefix . '.error' : 'error';
        if (!empty($this->errors)) {
            $this->modx->toPlaceholders($this->errors, $errorPrefix);

            $fields = $this->dictionary->toArray();
            $fields = $this->escapePlaceholders($fields);

            $this->modx->toPlaceholders($fields, $placeholderPrefix);

            return $this->showChangePasswordForm();
        }

        $this->validatePasswordLength();
        $this->confirmMatchedPasswords();

        if (!empty($this->errors)) {
            $errorMsg = $this->prepareFailureMessage();
            $this->modx->toPlaceholder('error_message', $errorMsg, $placeholderPrefix);
            $this->modx->toPlaceholders($this->errors, $errorPrefix);

            return $this->showChangePasswordForm();
        }

        $this->password = $this->dictionary->get('password_new');


        return true;
    }

    /**
     * Ensure the new password is at least the minimum length as specified in System Settings
     *
     * @return boolean
     */
    public function validatePasswordLength() {
        $validated = true;
        $fieldNewPassword = $this->getProperty('fieldNewPassword','password_new');
        $newPassword = $this->dictionary->get($fieldNewPassword);

        $minLength = $this->modx->getOption('password_min_length',null,8);
        if (empty($newPassword) || strlen($newPassword) < $minLength) {
            $this->errors[$fieldNewPassword] = $this->modx->lexicon('login.password_too_short',array('length' => $minLength));
            $validated = false;
        }
        return $validated;
    }

    /**
     * If set, confirm that the confirmation password matches the new password
     * @return boolean
     */
    public function confirmMatchedPasswords() {
        $validated = true;
        $fieldConfirmNewPassword = $this->getProperty('fieldConfirmNewPassword');
        /* if using confirm, ensure they match */
        if (!empty($fieldConfirmNewPassword)) {
            $confirmNewPassword = $this->dictionary->get($fieldConfirmNewPassword);
            $fieldNewPassword = $this->getProperty('fieldNewPassword','password_new');
            $newPassword = $this->dictionary->get($fieldNewPassword);
            if (empty($confirmNewPassword) || $newPassword != $confirmNewPassword) {
                $this->errors[$fieldConfirmNewPassword] = $this->modx->lexicon('login.password_no_match');
                $validated = false;
            }
        }
        return $validated;
    }

    /**
     * @param string $defaultErrorMessage
     * @return string
     */
    public function prepareFailureMessage($defaultErrorMessage = '') {
        $errorOutput = '';
        $errTpl = $this->getProperty('errTpl');
        $errors = $this->errors;
        if (!empty($errors)) {
            foreach ($errors as $error) {
                $errorOutput .= $this->modx->getChunk($errTpl,  array('msg' => $error));
            }
        } else {
            $errorOutput = $this->modx->getChunk($errTpl, array('msg' => $defaultErrorMessage));
        }
        return $errorOutput;
    }

    public function autoLogin() {
        if ($this->user == null) { return false; }

        $contexts = $this->getProperty('authenticateContexts', $this->modx->context->get('key'));

        $c = array(
            'login_context' => $this->modx->context->key,
            'add_contexts' => $contexts,
            'username' => $this->user->username,
            'password' => $this->password,
            'returnUrl' => '',
        );
        $this->modx->runProcessor('security/login',$c);

        return true;
    }    
}
