<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

namespace JustKnit\Controllers\Register;

use MODX\Revolution\modX;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use JustKnit\Model\JustKnitClientMeta;
use JustKnit\Model\JustKnitProduct;
use JustKnit\Model\JustKnitOrder;
use JustKnit\Model\JustKnitTransaction;
use JustKnit\Controllers\Register\Base;

class IpnDS24 extends Base {
        /** @var array $post An array of posted values from DS24 */
    public $post = [];
    /**
     * Load default properties for this controller.
     *
     * @return void
     */
    public function initialize()
    {
        $this->setDefaultProperties([
            'DS24_order_id'      => '',
            'DS24_product_id'    => '',
            'client_id'          => 1,
        ]);
    }

    /**
     * Handle the JustKnit Ipn logic.
     *
     * @return string
     */
    public function process()
    {
        if (!$this->hasPost()) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: no valid $_POST ');
            return '';
        }
        $fields = $this->dictionary->toArray();
        // Set fields for JustKnitTransaction
        $this->setProperty('DS24_order_id',$fields['order_id']);
        $this->setProperty('DS24_product_id',$fields['product_id']);
        $this->userID = $this->getUserByEmail($fields['email']);
        $this->user = $this->getUserById($this->userID);
        if (!$this->user) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: User not found with email '. $fields['email']);
/**
 * TEST ob die Transaction gespeichert wird, wenn keine UserId angegeben wird.
 *
 */
            //return '';
        }
        $this->profile = $this->user->getOne('Profile');
        $this->clientmeta = $this->getClientMetaByUserId($this->user->get('id'));
        $this->setProperty('client_id', $this->clientmeta->get('client_id'));
        $this->order_id = $this->getProperty('DS24_order_id');
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: Order not found with order_id '. $this->order_id);

        $this->order = $this->getOrder();
        if (!$this->order) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: Order not found with order_id '. $this->order->get('id').'orderID for this transaction is set to 1');
/** 
 * TODO
 * Bis die Sache läuft breche ich hier mal nicht ab. Sonst werden die ganzen IPN nicht gespeichert. 
 * Ich muss erst wissen, ob die order for der transaction erstellt wird.
 * Das ist auch wieder Quatsch. Weil wenn der User nicht vorhanden ist, kann die Transaction auch nicht gespeichert werden.
 */
//            return '';
            $this->setProperty('order_id', 1);
        } else {
            $fields['order_id'] = $this->order->get('id');
        }
        $this->product_id = $fields['product_id'];
        $this->product = $this->getProduct();
        if (!$this->product) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: product not found with product_id '. $fields['product_id']);
        }
        $fields['product_id'] = $this->product->get('id');
//        $fields = array_merge( $this->setProperties(),$fields);
        $this->setProperties($fields);
$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] $this->getProperties()'. print_r($this->getProperties(),1));

        $this->transaction = $this->modx->getObject(JustKnitTransaction::class, [
            'transaction_id' => $fields['transaction_id']
        ]);
        if (!$this->transaction) {
            $result = $this->runProcessor('CreateTransaction');
        }

        if (!$result) {
            $this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: Transaction could not be created '. $fields['transaction_id']);
            return '';
        }
        // check [transaction_type] if !payment deactivate modUser
        if (!in_array('payment', explode(',', $this->transaction->get('transaction_type')))) {
            $this->profile->set('blocked', true);
            $this->profile->set('blockedafter', time());

            if (!$this->profile->save()) {
                $modx->log(modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: Transaction Profile not blocked for User ' . $this->user->get('username'));
            }

        }





/*        if () {

        }
        // check if the
*/
/**
 * Hier muss dann rein, dass jede transaction gespeichert wird.
 * siehe @Brainstorm.jk@MODX3.ods.$DatenFlowIpn.
 * in der transaction sind dann byer_id, oder_id, product_id, und die ganzen Zahlungsdaten
 * incl. Verdienst und Provision.
 * über [transaction_type] => [payment, refund, chargeback, refund_request] wird dann
 * ausgelöst, falls eine Rückgabe erfolgt. Dann muss der modUser['active'] auf 0 gesetzt werden
 * und modUserProfile['blockedafter'] auf das aktuelle Datum
 *
 */


        return true;
    }
}
