<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

namespace JustKnit\Controllers\Register;

use MODX\Revolution\modX;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use JustKnit\Model\JustKnitClientMeta;
use JustKnit\Model\JustKnitProduct;
use JustKnit\Model\JustKnitOrder;
use JustKnit\Controllers\Register\Base;

class ThankYouPageDS24 extends Base {
    /** @var array $get An array of posted values from DS24 */
    public $get = [];
    /**
     * Load default properties for this controller.
     *
     * @return void
     */
    public function initialize()
    {
        $this->setDefaultProperties([
            'DS24_ARRAY_ENCRYPTPTION_VALIDATION_PREFIX'     =>   'ds24',
            'DS24_ARRAY_ENCRYPTPTION_VALIDATION_CHAR_COUNT' => 5,
            'encrypt_method'                                => 'AES-256-CBC',
        ]);
    }

    /**
     * Handle the JustKnit Register logic.
     *
     * @return string
     */
    public function process()
    {
    /**
    *
    * Hier muss aus den $_GET folgendes passieren:
    *  - mit dem typk und den Daten aus $_GET wird ein array erzeugt.
    *  - in dem array sind dann die Daten, die ich als Parameter im Produkt bei DS24 angegeben habe.
    *    danke/?order_id=[ORDER_ID]&product_id=[PRODUCT_ID]&buyer_id=[BUYER_ID]&invoice_url=[INVOICE_URL]
    *  - mit den Daten gebe ich dann die Werte aus meinen Tabellen aus:
    *    modUser, modUserProfile, JustKnitClientMeta, JustKnitProduct, JustKnitOrder
    *  - alles was ich dann habe wird in $scriptProperties übergeben.
    *  - das kann mein Snippet dann in ein chunk übergeben mit den Daten, die der User angegeben hat.
    *
    */
        if (!$this->hasGet()) {
            $this->modx->log(
                modX::LOG_LEVEL_ERROR,
                '[JustKnit] No GET-Properties were transferred ');
            return '';
        }

        $this->validateSha();
        if (!$this->shaIsValid) {
                $this->modx->log(
                modX::LOG_LEVEL_ERROR,
                '[JustKnit] invalid sha signature');
            return '';
        }

        // get product
        $productId = $this->getProductId();
        if (!$productId){
            $this->modx->log(
                modX::LOG_LEVEL_ERROR,
                '[JustKnit] no valid product_id in $_GET');
            return '';
        }
        if ($this->getProduct()) {
            $this->setProperty('productID', $this->product->get('id'));
        }
        //get User
        $client = $this->getClientByBuyerId($this->getProperty('buyer_id'));
        if ($client) {
            if ($this->getUserById($this->clientmeta->get('client_id'))) {
                if (!$this->getProfile()) {
                    $this->modx->log(
                        modX::LOG_LEVEL_ERROR,
                        '[JustKnit] no Client found ');
                    return '';
                }
            }
        }

        // get order_id
        $this->order_id = $this->getProperty('order_id');
        if ($this->getOrder()) {
            $this->setProperty('orderID', $this->order->get('id'));
        }
        if (!is_object($this->user) || !is_object($this->profile) || !is_object($this->clientmeta)) {
            $this->modx->log(
                        modX::LOG_LEVEL_ERROR,
                        '[JustKnit] no Client found ');
                    return '';
        }
        if (!is_object($this->product) || !is_object($this->order) ) {
            $this->modx->log(
                        modX::LOG_LEVEL_ERROR,
                        '[JustKnit] no Orderdata found ');
                    return '';
        }
        $properties = array_merge(
            $this->user->toArray(),
            $this->profile->toArray(),
            $this->clientmeta->toArray(),
            $this->product->toArray(),
            $this->order->toArray()
        );
        $properties = $this->cleanupKeys($properties);
        $this->setProperties($properties);
        $this->modx->toPlaceholders($properties);
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] $properties '. print_r($properties, 1));
        return '';
    }    
} 
