<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */
namespace JustKnit\Processors\Calculate;

use MODX\Revolution\modX;
use JustKnit\Model\JustKnitCalc;
use JustKnit\Model\JustKnitDim;
use JustKnit\Processors\Calculate\Base;

/**
 * Processor class which handles calculation when [cid] not set
 *  - new JustKnitCalc and JustKnitDim is created
 *
 * @package justknit
 * @subpackage processors
 */
class CreateCalc extends Base {
    /** @var JustKnitCalc $calc */
    public $calc = null;
    /** @var JustKnitDim $dim */
    public $dim = null;
    /**
     * @access public
     * @return mixed
     */
    public function process() {
        $this->fields = $this->dictionary->toArray();
        $this->fields = array_merge($this->controller->getProperties(), $this->fields);
        
        $calcFields = [];
        if (is_string($this->fields['Calcs'])) {
            $reqCalcs = explode(',', $this->fields['Calcs']);
        }
        foreach ($reqCalcs as $calc => $value) {
            $calc = trim($calc);
            foreach($this->fields as $k => $v) {
                $kn = preg_replace('/^'.$value.'_/','',$k);
                if ($kn=='pattern_meta'){
                    // replace html entity to validate json
                    $calcFields[$kn] = str_replace('&quot;', '"',$v);
                } else {
                    $calcFields[$kn] = $v;
                }
            }
            $this->calc[$value] = $this->modx->newObject(JustKnitCalc::class);
            if (!$this->calc[$value]) {
                $errorMsg = 'Failed to create object of type: JustKnitCalc';
                $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
                return false;
            }
            $this->calc[$value]->fromArray($calcFields);
            if (!$this->calc[$value]->save()) {
                $errorMsg = 'Failed to save object of type: JustKnitCalc';
                $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
                return false;
            }
        }
        $dimFields = [];
        if (is_string($this->fields['Dims'])) {
            $reqDims = explode(',', $this->fields['Dims']);
        }
        // add a new dim for each calc
        foreach($this->calc as $calc) {
            foreach($reqDims as $dim => $value) {
                $dim = trim($dim);
                foreach($this->fields as $k => $v) {
                    $dn = preg_replace('/^'.$value.'_/','',$k);
                    $dimFields[$dn] = $v;
                }
                $this->dim[$value] = $this->modx->newObject(JustKnitDim::class);
                if (!$this->dim[$value]) {
                    $errorMsg = 'Failed to create object of type: JustKnitDim';
                    $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
                    return false;
                }
                $this->dim[$value]->fromArray($dimFields);
                $this->dim[$value]->set('calc_id', $calc->get('id'));
                if (!$this->dim[$value]->save()) {
                    $errorMsg = 'Failed to save object of type: JustKnitDim';
                    $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
                    return false;
                }               
            }
        }
        return true;
    }
}









