<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */
namespace JustKnit\Processors\Calculate;

use MODX\Revolution\modX;
use JustKnit\Model\JustKnitCalc;
use JustKnit\Model\JustKnitDim;
use JustKnit\Processors\Calculate\Base;
/**
 * Processor class which handles calculation when [cid] not set
 *  - new JustKnitCalc and JustKnitDim is created
 *
 * @package justknit
 * @subpackage processors
 */
class UpdateCalc extends Base {
    /** @var JustKnitCalc $calc */
    public $calc = null;
    /** @var JustKnitDim $dim */
    public $dim = null;
    /**
     * @access public
     * @return mixed
     */
    public function process() {
        $this->fields = $this->dictionary->toArray();
        $this->fields = array_merge($this->controller->getProperties(), $this->fields);
        $calcFields = [];
        $dimFields = [];
        $this->calc = $this->controller->calc;
        if (!$this->calc) {
                $errorMsg = 'Failed to save object of type: JustKnitCalcs';
                $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
                return false;
        }
        foreach($this->fields as $k => $v) {
            // remove prefix '$calc' of fields
            $kn = preg_replace('/^'.$this->calc->get('calcname').'_/','',$k);
            if ($kn=='pattern_meta'){
                // replace html entity to validate json
                $calcFields[$kn] = str_replace('&quot;', '"',$v);
            } else {
                $calcFields[$kn] = $v;
            }
        }
        $this->calc->fromArray($calcFields);
        $this->calc->set('editedon', date('Y-m-d H:i:s'));
        if (!$this->calc->save()) {
            $errorMsg = 'Failed to save object of type: JustKnitCalcs';
            $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
            return false;
        }
        $this->dims = $this->controller->getDims($this->calc->get('id'));
        foreach($this->dims as $dim) {
            foreach($this->fields as $k => $v) {
                $dn = preg_replace('/^'.$dim->get('dimname').'_/','',$k);
                $dimFields[$dn] = $v;
            }
            $dim->fromArray($dimFields);
            if (!$dim->save()) {
                $errorMsg = 'Failed to save object of type: JustKnitDims';
                $this->modx->log(modX::LOG_LEVEL_ERROR, $errorMsg, '', 'saveCalcs Hook');
                return false;
            }
        }
    }
}










