<?php

/**
 * This file is part of the JustKnit package.
 *
 * @copyright zahlenhexe (Iris Hammer)
 * @license GNU General Public License v2.0 (and later)
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace JustKnit\Processors\Client;

use MODX\Revolution\Processors\Model\GetListProcessor;
use JustKnit\Model\JustKnitClientMeta;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use MODX\Revolution\modUserGroup;
use xPDO\Om\xPDOObject;
use xPDO\Om\xPDOQuery;
use MODX\Revolution\modX;

class GetList extends GetListProcessor {

//    public $classKey = JustKnitClientMeta::class;
    public $classKey = modUser::class;
    public $defaultSortField = 'id';
    public $defaultSortDirection = 'ASC';

    public function prepareQueryBeforeCount(xPDOQuery $c)
    {
        $c->leftJoin(modUserProfile::class, 'Profile');
        $c->rightJoin(JustKnitClientMeta::class, 'JustKnitClientMeta', 'modUser.id = JustKnitClientMeta.client_id');
        // collect all fields
        $flds = array_keys($this->modx->getFields(modUser::class));
        unset($flds['id']);
        $c->select($this->modx->getSelectColumns(
                modUser::class,
                'modUser',
                '',
                $flds
            ));
        // collect all fields
        unset($flds);
        $flds = array_keys($this->modx->getFields(modUserProfile::class));
        unset($flds['id']);
        $c->select($this->modx->getSelectColumns(
                modUserProfile::class,
                'Profile',
                '',
                $flds
            ));
        // collect all fields
        unset($flds);
        $flds = array_keys($this->modx->getFields(JustKnitClientMeta::class));
        $c->select($this->modx->getSelectColumns(
                JustKnitClientMeta::class,
                'JustKnitClientMeta',
                '',
                $flds
            ));
        unset($flds);
        $query = $this->getProperty('query');
        if (!empty($query)) {
            $c->where(
                [
                    'first_name:LIKE' => '%' . $query . '%',
                    'OR:last_name:LIKE' => '%' . $query . '%',
                    'OR:email' => '%' . $query . '%'
                ]
            );
        }
        $groupfilter = $this->getProperty('groupfilter', '');
        if (!empty($groupfilter)) {
            if ($groupfilter == 'nogroup') {
                $c->where(['User.primary_group' => null]);
            } else {
                $c->where(['User.primary_group' => $groupfilter]);
            }
        }
        $blockedafterfilter = $this->getProperty('blockedafterfilter', '');
        if ($blockedafterfilter) {
            $c->where(['Profile.blockedafter:>=' => time(), 'OR:Profile.blockedafter:=' => 0 ]);
        }
        $thisloginfilter = $this->getProperty('thisloginfilter', '');
        $interval = $this->modx->getOption('session_cookie_lifetime');
        $time = time();
        $startTime = $time - $interval;
        if ($thisloginfilter) {
            $c->where(['Profile.thislogin:>=' => $startTime,
        'AND:Profile.thislogin:<=' => $time]);
        }

//$c->prepare();
//$this->modx->log(modX::LOG_LEVEL_ERROR,'$c: '. $c->toSQL());

        return $c;
    }

    public function prepareQueryAfterCount(xPDOQuery $c)
    {
        // collect all fields
        $flds = array_keys($this->modx->getFields(modUser::class));
        unset($flds['id']);
        $c->select($this->modx->getSelectColumns(
            modUser::class,
            'modUser',
            '',
            $flds
        ));
        // collect all fields
        unset($flds);
        $flds = array_keys($this->modx->getFields(modUserProfile::class));
        unset($flds['id']);
        $c->select($this->modx->getSelectColumns(
            modUserProfile::class,
            'Profile',
            '',
            $flds
        ));
        // collect all fields
        unset($flds);
        $flds = array_keys($this->modx->getFields(JustKnitClientMeta::class));
        $c->select($this->modx->getSelectColumns(
            JustKnitClientMeta::class,
            'JustKnitClientMeta',
            '',
            $flds
        ));
//$c->prepare();
//$this->modx->log(modX::LOG_LEVEL_ERROR,'$c: '. $c->toSQL());
        return $c;
    }

    public function prepareRow(xPDOObject $object) {
        $objectArray = $object->toArray();

        $managerDateFormat = $this->modx->getOption('manager_date_format', null, 'Y-m-d');
        $managerTimeFormat = $this->modx->getOption('manager_time_format', null, 'H:i');
        $dateTimeFormat = $managerDateFormat.' '.$managerTimeFormat;

        $objectArray['blockedafter'] = !empty($objectArray['blockedafter']) ? date($dateTimeFormat,
            $objectArray['blockedafter']) : '';
        // client_deletedafter
        $objectArray['client_deletedafter'] = !empty($objectArray['client_deletedafter']) ? date($dateTimeFormat,
            $objectArray['client_deletedafter']) : '';
        //lastlogin
        $objectArray['lastlogin'] = !empty($objectArray['lastlogin']) ? date($dateTimeFormat,
            $objectArray['lastlogin']) : '';

        return $objectArray;
    }
}
