<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */

namespace JustKnit\Processors\Register;

use JustKnit\Register\Register;
use MODX\Revolution\modX;
/**
 * Abstracts processors into a class.
 *
 * @package justknit
 * @subpackage processors
 */
abstract class Base {

    /** @var Register $register */
    public $register = null;

    /** @var object $controller */
    public $controller = null;

    /** @var Dictionary $dictionary */
    public $dictionary = null;

    /** @var array $config */
    public $config = [];

    /**
     * Constructor for the Base register processor.
     *
     * @param Register &$register A reference to the Register instance
     * @param object &$controller
     * @param array $config
     */
    public function __construct(Register &$register, &$controller, array $config = [])
    {
        $this->modx = &$register->modx;
        $this->register = &$register;
        $this->controller = &$controller;
        $this->dictionary = &$controller->dictionary;
        $this->config = array_merge($this->config, $config);
    }

    abstract public function process();
}
