<?php
/**
 * This file is part of the JustKnit package.
 *
 * @copyright JustKnit (Iris Hammer) <iris@justknit.de>
 * @license All rights reserved (@https://dejure.org/gesetze/UrhG/69a.html)
 * Created on 03-20-2023
 *
 * @package justknit
 */
namespace JustKnit\Processors\Register;

use MODX\Revolution\modX;
use JustKnit\Model\JustKnitTransaction;
use JustKnit\Processors\Register\Base;

/**
 * Processor class which handles registration when posted [email] not exists
 *  - new MODX user is created
 *  - [modUserProfile] and [JustKnitClientMeta] is filled with data
 *
 * @package justknit
 * @subpackage processors
 */
class CreateTransaction extends Base {

    /**
     * @access public
     * @return mixed
     */
    public function process() {
        $this->transaction = $this->modx->newObject(JustKnitTransaction::class);
        $fields = $this->controller->getProperties();
$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] Payment: $fields '. print_r($fields,1));

        $this->transaction->fromArray($fields);
        if (!$this->transaction->save()) {
            $this->modx->log(modX::LOG_LEVEL_ERROR, '[JustKnit] Could not save new transaction - ' . $fields['transaction_id'] );
            $this->controller->setResponseMessage('Could not save new transaction ' . $fields['transaction_id']);
            return $this->modx->lexicon('justknit.transaction_err_save');
        }

        return true;
    }
}
